.. QuadMoM documentation master file, created by
   sphinx-quickstart on Sat Jul  9 22:20:38 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=========================================
**Welcome to QuadMomPy's documentation!**
=========================================

QuadMomPy is a library for all sorts of fun with moments, Gaussian quadratures, orthogonal polynomials and quadrature-based moment methods for the solution of spatially homogeneous population balance equations.

Contents
--------
.. toctree::
   :maxdepth: 3

   modules
   install
   usage


Indices and tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
